@@ -20,16 +20,11 @@ def visit_Attribute(
         parent: ast.AST,
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-            state.settings.min_version >= (3,) and
             isinstance(node.value, ast.Name) and
             node.value.id == 'typing' and
             node.attr == 'Text'
     ):
-        func = functools.partial(
-            replace_name,
-            name=node.attr,
-            new='str',
-        )
+        func = functools.partial(replace_name, name=node.attr, new='str')
         yield ast_to_offset(node), func
 
 
@@ -39,14 +34,6 @@ def visit_Name(
         node: ast.Name,
         parent: ast.AST,
 ) -> Iterable[tuple[Offset, TokenFunc]]:
-    if (
-            state.settings.min_version >= (3,) and
-            node.id in state.from_imports['typing'] and
-            node.id == 'Text'
-    ):
-        func = functools.partial(
-            replace_name,
-            name=node.id,
-            new='str',
-        )
+    if node.id in state.from_imports['typing'] and node.id == 'Text':
+        func = functools.partial(replace_name, name=node.id, new='str')
         yield ast_to_offset(node), func
